import axios from 'axios';
import dotenv from 'dotenv';

dotenv.config();

const API_URL = process.env.API_URL;
const INSTANCE_NAME = process.env.INSTANCE_NAME;
const API_KEY = process.env.API_KEY;

if (!API_URL || !INSTANCE_NAME || !API_KEY) {
  throw new Error('Required environment variables are not defined.');
}

// Send a message with optional mentions
export async function sendMessage(phone: string, message: string, mentions: string[] = []) {
  try {
    let payload: any;
    
    if (mentions.length > 0) {
      // Format with mentions
      payload = {
        number: phone,
        options: {
          delay: 1200,
          presence: 'composing',
          linkPreview: false,
          mentions: {
            everyOne: false, // Set to false since we're mentioning specific users, not everyone
            mentioned: mentions.map(phone => phone.split('@')[0]) // Strip @s.whatsapp.net
          }
        },
        textMessage: {
          text: message
        }
      };
    } else {
      // Simple message format
      payload = {
        number: phone,
        text: message
      };
    }

    await axios.post(`${API_URL}/message/sendText/${INSTANCE_NAME}`, payload, {
      headers: {
        'Content-Type': 'application/json',
        apikey: API_KEY,
      },
    });
  } catch (error) {
    console.error('Error sending message:', error);
  }
}
