import { query, execute } from '../database/db';
import { Task } from '../models/task';

// Find and clean up orphaned tasks
export function cleanupOrphanedTasks() {
  try {
    // Find tasks assigned to non-existent users
    const orphanedTasks = query(`
      SELECT t.id 
      FROM tasks t
      LEFT JOIN users u ON t.assigned_to = u.phone_number
      WHERE t.assigned_to != '' 
        AND u.phone_number IS NULL
    `);

    if (orphanedTasks.length > 0) {
      console.log(`Found ${orphanedTasks.length} orphaned tasks, cleaning up...`);
      
      // Unassign the tasks
      execute(`
        UPDATE tasks 
        SET assigned_to = ''
        WHERE id IN (${orphanedTasks.map(t => t.id).join(',')})
      `);
    }

    return orphanedTasks.length;
  } catch (error) {
    console.error('Error during cleanup:', error);
    return 0;
  }
}
